@@ -16,7 +16,11 @@
   switch(
     vendor_cache[["vendor"]],
     "boto" = list(
-      "aws-global" = list(endpoint = "s3.amazonaws.com", global = TRUE),
+      "aws-global" = list(
+        endpoint = "s3.amazonaws.com",
+        global = TRUE,
+        signing_region = "us-east-1"
+      ),
       "us-east-1" = list(endpoint = "s3.amazonaws.com", global = TRUE),
       "^(us|eu|ap|sa|ca|me|af|il|mx)\\-\\w+\\-\\d+$" = list(
         endpoint = "s3.{region}.amazonaws.com",
@@ -48,54 +52,21 @@
       )
     ),
     "js" = list(
-      "us-gov-west-1" = list(
-        endpoint = "s3.{region}.amazonaws.com",
-        global = FALSE
-      ),
-      "us-west-1" = list(
-        endpoint = "s3.{region}.amazonaws.com",
-        global = FALSE
-      ),
-      "us-west-2" = list(
-        endpoint = "s3.{region}.amazonaws.com",
-        global = FALSE
-      ),
-      "eu-west-1" = list(
-        endpoint = "s3.{region}.amazonaws.com",
-        global = FALSE
-      ),
-      "ap-southeast-1" = list(
-        endpoint = "s3.{region}.amazonaws.com",
-        global = FALSE
-      ),
-      "ap-southeast-2" = list(
-        endpoint = "s3.{region}.amazonaws.com",
-        global = FALSE
-      ),
-      "ap-northeast-1" = list(
-        endpoint = "s3.{region}.amazonaws.com",
-        global = FALSE
-      ),
-      "sa-east-1" = list(
-        endpoint = "s3.{region}.amazonaws.com",
-        global = FALSE
-      ),
+      "us-gov-west-1" = list(endpoint = "s3.{region}.amazonaws.com", global = FALSE),
+      "us-west-1" = list(endpoint = "s3.{region}.amazonaws.com", global = FALSE),
+      "us-west-2" = list(endpoint = "s3.{region}.amazonaws.com", global = FALSE),
+      "eu-west-1" = list(endpoint = "s3.{region}.amazonaws.com", global = FALSE),
+      "ap-southeast-1" = list(endpoint = "s3.{region}.amazonaws.com", global = FALSE),
+      "ap-southeast-2" = list(endpoint = "s3.{region}.amazonaws.com", global = FALSE),
+      "ap-northeast-1" = list(endpoint = "s3.{region}.amazonaws.com", global = FALSE),
+      "sa-east-1" = list(endpoint = "s3.{region}.amazonaws.com", global = FALSE),
       "us-east-1" = list(endpoint = "s3.amazonaws.com", global = FALSE),
       "*" = list(endpoint = "s3.{region}.amazonaws.com", global = FALSE),
       "cn-*" = list(endpoint = "s3.{region}.amazonaws.com.cn", global = FALSE),
-      "eu-isoe-*" = list(
-        endpoint = "s3.{region}.cloud.adc-e.uk",
-        global = FALSE
-      ),
+      "eu-isoe-*" = list(endpoint = "s3.{region}.cloud.adc-e.uk", global = FALSE),
       "us-iso-*" = list(endpoint = "s3.{region}.c2s.ic.gov", global = FALSE),
-      "us-isob-*" = list(
-        endpoint = "s3.{region}.sc2s.sgov.gov",
-        global = FALSE
-      ),
-      "us-isof-*" = list(
-        endpoint = "s3.{region}.csp.hci.ic.gov",
-        global = FALSE
-      )
+      "us-isob-*" = list(endpoint = "s3.{region}.sc2s.sgov.gov", global = FALSE),
+      "us-isof-*" = list(endpoint = "s3.{region}.csp.hci.ic.gov", global = FALSE)
     )
   )
 }
