@@ -2,11 +2,7 @@
 
 # Build tests
 
-svc <- Client(
-  client_info = ClientInfo(
-    endpoint = "https://test"
-  )
-)
+svc <- Client(client_info = ClientInfo(endpoint = "https://test"))
 svc$handlers$build <- HandlerList(restjson_build)
 UUID_V4_PATTERN <- "[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}"
 
@@ -35,9 +31,7 @@ test_that("URI parameter with no location name", {
     )
     return(populate(args, interface))
   }
-  input <- op_input2(
-    PipelineId = "foo"
-  )
+  input <- op_input2(PipelineId = "foo")
   req <- new_request(svc, op2, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -53,13 +47,14 @@ test_that("URI parameter with location name", {
   op_input3 <- function(Foo) {
     args <- list(Foo = Foo)
     interface <- Structure(
-      Foo = Scalar(type = "string", .tags = list(location = "uri", locationName = "PipelineId"))
+      Foo = Scalar(
+        type = "string",
+        .tags = list(location = "uri", locationName = "PipelineId")
+      )
     )
     return(populate(args, interface))
   }
-  input <- op_input3(
-    Foo = "bar"
-  )
+  input <- op_input3(Foo = "bar")
   req <- new_request(svc, op3, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -67,21 +62,18 @@ test_that("URI parameter with location name", {
 })
 
 test_that("query string list of strings", {
-  op4 <- Operation(
-    name = "OperationName",
-    http_method = "GET",
-    http_path = "/path"
-  )
+  op4 <- Operation(name = "OperationName", http_method = "GET", http_path = "/path")
   op_input4 <- function(Items) {
     args <- list(Items = Items)
     interface <- Structure(
-      Items = List(Scalar(type = "string"), .tags = list(location = "querystring", locationName = "item"))
+      Items = List(
+        Scalar(type = "string"),
+        .tags = list(location = "querystring", locationName = "item")
+      )
     )
     return(populate(args, interface))
   }
-  input <- op_input4(
-    Items = list("value1", "value2")
-  )
+  input <- op_input4(Items = list("value1", "value2"))
   req <- new_request(svc, op4, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -102,17 +94,14 @@ test_that("query string map of strings", {
     )
     return(populate(args, interface))
   }
-  input <- op_input5(
-    PipelineId = "foo",
-    QueryDoc = list(
-      bar = "baz",
-      fizz = "buzz"
-    )
-  )
+  input <- op_input5(PipelineId = "foo", QueryDoc = list(bar = "baz", fizz = "buzz"))
   req <- new_request(svc, op5, input, NULL)
   req <- build(req)
   r <- req$http_request
-  expect_equal(build_url(r$url), "https://test/2014-01-01/jobsByPipeline/foo?bar=baz&fizz=buzz")
+  expect_equal(
+    build_url(r$url),
+    "https://test/2014-01-01/jobsByPipeline/foo?bar=baz&fizz=buzz"
+  )
 })
 
 test_that("query string map of lists of strings", {
@@ -125,39 +114,39 @@ test_that("query string map of lists of strings", {
     args <- list(PipelineId = PipelineId, QueryDoc = QueryDoc)
     interface <- Structure(
       PipelineId = Scalar(type = "string", .tags = list(location = "uri")),
-      QueryDoc = Map(List(Scalar(type = "string")), .tags = list(location = "querystring"))
+      QueryDoc = Map(
+        List(Scalar(type = "string")),
+        .tags = list(location = "querystring")
+      )
     )
     return(populate(args, interface))
   }
   input <- op_input6(
     PipelineId = "id",
-    QueryDoc = list(
-      fizz = c("buzz", "pop"),
-      foo = c("bar", "baz")
-    )
+    QueryDoc = list(fizz = c("buzz", "pop"), foo = c("bar", "baz"))
   )
   req <- new_request(svc, op6, input, NULL)
   req <- build(req)
   r <- req$http_request
-  expect_equal(build_url(r$url), "https://test/2014-01-01/jobsByPipeline/id?fizz=buzz&fizz=pop&foo=bar&foo=baz")
+  expect_equal(
+    build_url(r$url),
+    "https://test/2014-01-01/jobsByPipeline/id?fizz=buzz&fizz=pop&foo=bar&foo=baz"
+  )
 })
 
 test_that("query string with bool (true)", {
-  op7 <- Operation(
-    name = "OperationName",
-    http_method = "GET",
-    http_path = "/path"
-  )
+  op7 <- Operation(name = "OperationName", http_method = "GET", http_path = "/path")
   op_input7 <- function(BoolQuery) {
     args <- list(BoolQuery = BoolQuery)
     interface <- Structure(
-      BoolQuery = Scalar(type = "boolean", .tags = list(location = "querystring", locationName = "bool-query"))
+      BoolQuery = Scalar(
+        type = "boolean",
+        .tags = list(location = "querystring", locationName = "bool-query")
+      )
     )
     return(populate(args, interface))
   }
-  input <- op_input7(
-    BoolQuery = TRUE
-  )
+  input <- op_input7(BoolQuery = TRUE)
   req <- new_request(svc, op7, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -165,21 +154,18 @@ test_that("query string with bool (true)", {
 })
 
 test_that("query string with bool (false)", {
-  op8 <- Operation(
-    name = "OperationName",
-    http_method = "GET",
-    http_path = "/path"
-  )
+  op8 <- Operation(name = "OperationName", http_method = "GET", http_path = "/path")
   op_input8 <- function(BoolQuery) {
     args <- list(BoolQuery = BoolQuery)
     interface <- Structure(
-      BoolQuery = Scalar(type = "boolean", .tags = list(location = "querystring", locationName = "bool-query"))
+      BoolQuery = Scalar(
+        type = "boolean",
+        .tags = list(location = "querystring", locationName = "bool-query")
+      )
     )
     return(populate(args, interface))
   }
-  input <- op_input8(
-    BoolQuery = FALSE
-  )
+  input <- op_input8(BoolQuery = FALSE)
   req <- new_request(svc, op8, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -195,21 +181,29 @@ test_that("URI and query string parameters", {
   op_input9 <- function(Ascending, PageToken, PipelineId) {
     args <- list(Ascending = Ascending, PageToken = PageToken, PipelineId = PipelineId)
     interface <- Structure(
-      Ascending = Scalar(type = "string", .tags = list(location = "querystring", locationName = "Ascending")),
-      PageToken = Scalar(type = "string", .tags = list(location = "querystring", locationName = "PageToken")),
-      PipelineId = Scalar(type = "string", .tags = list(location = "uri", locationName = "PipelineId"))
+      Ascending = Scalar(
+        type = "string",
+        .tags = list(location = "querystring", locationName = "Ascending")
+      ),
+      PageToken = Scalar(
+        type = "string",
+        .tags = list(location = "querystring", locationName = "PageToken")
+      ),
+      PipelineId = Scalar(
+        type = "string",
+        .tags = list(location = "uri", locationName = "PipelineId")
+      )
     )
     return(populate(args, interface))
   }
-  input <- op_input9(
-    Ascending = "true",
-    PageToken = "bar",
-    PipelineId = "foo"
-  )
+  input <- op_input9(Ascending = "true", PageToken = "bar", PipelineId = "foo")
   req <- new_request(svc, op9, input, NULL)
   req <- build(req)
   r <- req$http_request
-  expect_equal(build_url(r$url), "https://test/2014-01-01/jobsByPipeline/foo?Ascending=true&PageToken=bar")
+  expect_equal(
+    build_url(r$url),
+    "https://test/2014-01-01/jobsByPipeline/foo?Ascending=true&PageToken=bar"
+  )
 })
 
 test_that("URI, query string, and JSON body", {
@@ -219,31 +213,42 @@ test_that("URI, query string, and JSON body", {
     http_path = "/2014-01-01/jobsByPipeline/{PipelineId}"
   )
   op_input10 <- function(Ascending, Config, PageToken, PipelineId) {
-    args <- list(Ascending = Ascending, Config = Config, PageToken = PageToken, PipelineId = PipelineId)
+    args <- list(
+      Ascending = Ascending,
+      Config = Config,
+      PageToken = PageToken,
+      PipelineId = PipelineId
+    )
     interface <- Structure(
-      Ascending = Scalar(type = "string", .tags = list(location = "querystring", locationName = "Ascending")),
-      Config = Structure(
-        A = Scalar(type = "string"),
-        B = Scalar(type = "string")
+      Ascending = Scalar(
+        type = "string",
+        .tags = list(location = "querystring", locationName = "Ascending")
       ),
-      PageToken = Scalar(type = "string", .tags = list(location = "querystring", locationName = "PageToken")),
-      PipelineId = Scalar(type = "string", .tags = list(location = "uri", locationName = "PipelineId"))
+      Config = Structure(A = Scalar(type = "string"), B = Scalar(type = "string")),
+      PageToken = Scalar(
+        type = "string",
+        .tags = list(location = "querystring", locationName = "PageToken")
+      ),
+      PipelineId = Scalar(
+        type = "string",
+        .tags = list(location = "uri", locationName = "PipelineId")
+      )
     )
     return(populate(args, interface))
   }
   input <- op_input10(
     Ascending = "true",
-    Config = list(
-      A = "one",
-      B = "two"
-    ),
+    Config = list(A = "one", B = "two"),
     PageToken = "bar",
     PipelineId = "foo"
   )
   req <- new_request(svc, op10, input, NULL)
   req <- build(req)
   r <- req$http_request
-  expect_equal(build_url(r$url), "https://test/2014-01-01/jobsByPipeline/foo?Ascending=true&PageToken=bar")
+  expect_equal(
+    build_url(r$url),
+    "https://test/2014-01-01/jobsByPipeline/foo?Ascending=true&PageToken=bar"
+  )
   expect_equal(r$body, '{"Config":{"A":"one","B":"two"}}')
 })
 
@@ -254,33 +259,48 @@ test_that("URI, query string, JSON body, and header", {
     http_path = "/2014-01-01/jobsByPipeline/{PipelineId}"
   )
   op_input11 <- function(Ascending, Checksum, Config, PageToken, PipelineId) {
-    args <- list(Ascending = Ascending, Checksum = Checksum, Config = Config, PageToken = PageToken, PipelineId = PipelineId)
+    args <- list(
+      Ascending = Ascending,
+      Checksum = Checksum,
+      Config = Config,
+      PageToken = PageToken,
+      PipelineId = PipelineId
+    )
     interface <- Structure(
-      Ascending = Scalar(type = "string", .tags = list(location = "querystring", locationName = "Ascending")),
-      Checksum = Scalar(type = "string", .tags = list(location = "header", locationName = "x-amz-checksum")),
-      Config = Structure(
-        A = Scalar(type = "string"),
-        B = Scalar(type = "string")
+      Ascending = Scalar(
+        type = "string",
+        .tags = list(location = "querystring", locationName = "Ascending")
       ),
-      PageToken = Scalar(type = "string", .tags = list(location = "querystring", locationName = "PageToken")),
-      PipelineId = Scalar(type = "string", .tags = list(location = "uri", locationName = "PipelineId"))
+      Checksum = Scalar(
+        type = "string",
+        .tags = list(location = "header", locationName = "x-amz-checksum")
+      ),
+      Config = Structure(A = Scalar(type = "string"), B = Scalar(type = "string")),
+      PageToken = Scalar(
+        type = "string",
+        .tags = list(location = "querystring", locationName = "PageToken")
+      ),
+      PipelineId = Scalar(
+        type = "string",
+        .tags = list(location = "uri", locationName = "PipelineId")
+      )
     )
     return(populate(args, interface))
   }
   input <- op_input11(
     Ascending = "true",
     Checksum = "12345",
-    Config = list(
-      A = "one",
-      B = "two"
-    ),
+    Config = list(A = "one", B = "two"),
     PageToken = "bar",
     PipelineId = "foo"
   )
   req <- new_request(svc, op11, input, NULL)
   req <- build(req)
   r <- req$http_request
-  expect_equal(build_url(r$url), "https://test/2014-01-01/jobsByPipeline/foo?Ascending=true&PageToken=bar")
+  expect_equal(
+    build_url(r$url),
+    "https://test/2014-01-01/jobsByPipeline/foo?Ascending=true&PageToken=bar"
+  )
   expect_equal(r$body, '{"Config":{"A":"one","B":"two"}}')
   expect_equal(r$header[["x-amz-checksum"]], "12345")
 })
@@ -295,17 +315,19 @@ test_that("streaming payload", {
     args <- list(Body = Body, Checksum = Checksum, VaultName = VaultName)
     interface <- Structure(
       Body = Scalar(type = "blob", .tags = list(locationName = "body")),
-      Checksum = Scalar(type = "string", .tags = list(location = "header", locationName = "x-amz-sha256-tree-hash")),
-      VaultName = Scalar(type = "string", .tags = list(location = "uri", locationName = "vaultName", required = TRUE)),
+      Checksum = Scalar(
+        type = "string",
+        .tags = list(location = "header", locationName = "x-amz-sha256-tree-hash")
+      ),
+      VaultName = Scalar(
+        type = "string",
+        .tags = list(location = "uri", locationName = "vaultName", required = TRUE)
+      ),
       .tags = list(payload = "Body")
     )
     return(populate(args, interface))
   }
-  input <- op_input12(
-    Body = charToRaw("contents"),
-    Checksum = "foo",
-    VaultName = "name"
-  )
+  input <- op_input12(Body = charToRaw("contents"), Checksum = "foo", VaultName = "name")
   req <- new_request(svc, op12, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -324,14 +346,14 @@ test_that("serialize blobs in body", {
     args <- list(Bar = Bar, Foo = Foo)
     interface <- Structure(
       Bar = Scalar(type = "blob"),
-      Foo = Scalar(type = "string", .tags = list(location = "uri", locationName = "Foo", required = TRUE))
+      Foo = Scalar(
+        type = "string",
+        .tags = list(location = "uri", locationName = "Foo", required = TRUE)
+      )
     )
     return(populate(args, interface))
   }
-  input <- op_input13(
-    Bar = charToRaw("Blob param"),
-    Foo = "foo_name"
-  )
+  input <- op_input13(Bar = charToRaw("Blob param"), Foo = "foo_name")
   req <- new_request(svc, op13, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -339,11 +361,7 @@ test_that("serialize blobs in body", {
   expect_equal(r$body, '{"Bar":"QmxvYiBwYXJhbQ=="}')
 })
 
-op14 <- Operation(
-  name = "OperationName",
-  http_method = "POST",
-  http_path = "/"
-)
+op14 <- Operation(name = "OperationName", http_method = "POST", http_path = "/")
 op_input14 <- function(Foo = NULL) {
   args <- list(Foo = Foo)
   interface <- Structure(
@@ -354,9 +372,7 @@ op_input14 <- function(Foo = NULL) {
 }
 
 test_that("blob payload", {
-  input <- op_input14(
-    Foo = charToRaw("bar")
-  )
+  input <- op_input14(Foo = charToRaw("bar"))
   req <- new_request(svc, op14, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -373,11 +389,7 @@ test_that("empty blob payload", {
   expect_null(r$body)
 })
 
-op15 <- Operation(
-  name = "OperationName",
-  http_method = "POST",
-  http_path = "/"
-)
+op15 <- Operation(name = "OperationName", http_method = "POST", http_path = "/")
 op_input15 <- function(Foo = NULL) {
   args <- list(Foo = Foo)
   interface <- Structure(
@@ -391,11 +403,7 @@ op_input15 <- function(Foo = NULL) {
 }
 
 test_that("structure payload", {
-  input <- op_input15(
-    Foo = list(
-      Baz = "bar"
-    )
-  )
+  input <- op_input15(Foo = list(Baz = "bar"))
   req <- new_request(svc, op15, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -413,15 +421,14 @@ test_that("empty structure payload", {
 })
 
 test_that("omit null query string parameters", {
-  op16 <- Operation(
-    name = "OperationName",
-    http_method = "POST",
-    http_path = "/path"
-  )
+  op16 <- Operation(name = "OperationName", http_method = "POST", http_path = "/path")
   op_input16 <- function(Foo = NULL) {
     args <- list(Foo = Foo)
     interface <- Structure(
-      Foo = Scalar(type = "string", .tags = list(location = "querystring", locationName = "param-name"))
+      Foo = Scalar(
+        type = "string",
+        .tags = list(location = "querystring", locationName = "param-name")
+      )
     )
     return(populate(args, interface))
   }
@@ -442,13 +449,14 @@ test_that("serialize empty string query string parameters", {
   op_input17 <- function(Foo = NULL) {
     args <- list(Foo = Foo)
     interface <- Structure(
-      Foo = Scalar(type = "string", .tags = list(location = "querystring", locationName = "param-name"))
+      Foo = Scalar(
+        type = "string",
+        .tags = list(location = "querystring", locationName = "param-name")
+      )
     )
     return(populate(args, interface))
   }
-  input <- op_input17(
-    Foo = ""
-  )
+  input <- op_input17(Foo = "")
   req <- new_request(svc, op17, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -459,21 +467,13 @@ test_that("serialize empty string query string parameters", {
 # TODO: RecursiveStructs.
 
 test_that("timestamp value", {
-  op18 <- Operation(
-    name = "OperationName",
-    http_method = "POST",
-    http_path = "/path"
-  )
+  op18 <- Operation(name = "OperationName", http_method = "POST", http_path = "/path")
   op_input18 <- function(TimeArg) {
     args <- list(TimeArg = TimeArg)
-    interface <- Structure(
-      TimeArg = Scalar(type = "timestamp")
-    )
+    interface <- Structure(TimeArg = Scalar(type = "timestamp"))
     return(populate(args, interface))
   }
-  input <- op_input18(
-    TimeArg = unix_time(1422172800)
-  )
+  input <- op_input18(TimeArg = unix_time(1422172800))
   req <- new_request(svc, op18, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -482,21 +482,18 @@ test_that("timestamp value", {
 })
 
 test_that("timestamp value in header", {
-  op19 <- Operation(
-    name = "OperationName",
-    http_method = "POST",
-    http_path = "/path"
-  )
+  op19 <- Operation(name = "OperationName", http_method = "POST", http_path = "/path")
   op_input19 <- function(TimeArgInHeader) {
     args <- list(TimeArgInHeader = TimeArgInHeader)
     interface <- Structure(
-      TimeArgInHeader = Scalar(type = "timestamp", .tags = list(location = "header", locationName = "x-amz-timearg"))
+      TimeArgInHeader = Scalar(
+        type = "timestamp",
+        .tags = list(location = "header", locationName = "x-amz-timearg")
+      )
     )
     return(populate(args, interface))
   }
-  input <- op_input19(
-    TimeArgInHeader = unix_time(1422172800)
-  )
+  input <- op_input19(TimeArgInHeader = unix_time(1422172800))
   req <- new_request(svc, op19, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -505,21 +502,18 @@ test_that("timestamp value in header", {
 })
 
 test_that("timestamp value in JSON body", {
-  op20 <- Operation(
-    name = "OperationName",
-    http_method = "POST",
-    http_path = "/path"
-  )
+  op20 <- Operation(name = "OperationName", http_method = "POST", http_path = "/path")
   op_input20 <- function(TimeArg) {
     args <- list(TimeArg = TimeArg)
     interface <- Structure(
-      TimeArg = Scalar(type = "timestamp", .tags = list(locationName = "timestamp_location"))
+      TimeArg = Scalar(
+        type = "timestamp",
+        .tags = list(locationName = "timestamp_location")
+      )
     )
     return(populate(args, interface))
   }
-  input <- op_input20(
-    TimeArg = unix_time(1422172800)
-  )
+  input <- op_input20(TimeArg = unix_time(1422172800))
   req <- new_request(svc, op20, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -528,11 +522,7 @@ test_that("timestamp value in JSON body", {
 })
 
 test_that("string payload", {
-  op21 <- Operation(
-    name = "OperationName",
-    http_method = "POST",
-    http_path = "/path"
-  )
+  op21 <- Operation(name = "OperationName", http_method = "POST", http_path = "/path")
   op_input21 <- function(Foo) {
     args <- list(Foo = Foo)
     interface <- Structure(
@@ -541,9 +531,7 @@ test_that("string payload", {
     )
     return(populate(args, interface))
   }
-  input <- op_input21(
-    Foo = "bar"
-  )
+  input <- op_input21(Foo = "bar")
   req <- new_request(svc, op21, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -551,11 +539,7 @@ test_that("string payload", {
   expect_equal(r$body, "bar")
 })
 
-op22 <- Operation(
-  name = "OperationName",
-  http_method = "POST",
-  http_path = "/path"
-)
+op22 <- Operation(name = "OperationName", http_method = "POST", http_path = "/path")
 op_input22 <- function(Token = NULL) {
   args <- list(Token = Token)
   interface <- Structure(
@@ -565,9 +549,7 @@ op_input22 <- function(Token = NULL) {
 }
 
 test_that("idempotency token", {
-  input <- op_input22(
-    Token = "abc123"
-  )
+  input <- op_input22(Token = "abc123")
   req <- new_request(svc, op22, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -604,7 +586,10 @@ test_that("unmarshal scalar members", {
     FalseBool = Scalar(type = "boolean"),
     Float = Scalar(type = "float"),
     ImaHeader = Scalar(type = "string", .tags = list(location = "header")),
-    ImaHeaderLocation = Scalar(type = "string", .tags = list(location = "header", locationName = "X-Foo")),
+    ImaHeaderLocation = Scalar(
+      type = "string",
+      .tags = list(location = "header", locationName = "X-Foo")
+    ),
     Long = Scalar(type = "long"),
     Num = Scalar(type = "integer"),
     StatusCode = Scalar(type = "integer", .tags = list(location = "statusCode")),
@@ -614,7 +599,9 @@ test_that("unmarshal scalar members", {
   req <- new_request(svc, op, NULL, op_output1)
   req$http_response <- HttpResponse(
     status_code = 200,
-    body = charToRaw("{\"Str\": \"myname\", \"Num\": 123, \"FalseBool\": false, \"TrueBool\": true, \"Float\": 1.2, \"Double\": 1.3, \"Long\": 200, \"Char\": \"a\"}")
+    body = charToRaw(
+      "{\"Str\": \"myname\", \"Num\": 123, \"FalseBool\": false, \"TrueBool\": true, \"Float\": 1.2, \"Double\": 1.3, \"Long\": 200, \"Char\": \"a\"}"
+    )
   )
   req$http_response$header[["ImaHeader"]] <- "test"
   req$http_response$header[["X-Foo"]] <- "abc"
@@ -644,7 +631,9 @@ test_that("unmarshal blob member", {
   req <- new_request(svc, op, NULL, op_output2)
   req$http_response <- HttpResponse(
     status_code = 200,
-    body = charToRaw("{\"BlobMember\": \"aGkh\", \"StructMember\": {\"foo\": \"dGhlcmUh\"}}")
+    body = charToRaw(
+      "{\"BlobMember\": \"aGkh\", \"StructMember\": {\"foo\": \"dGhlcmUh\"}}"
+    )
   )
   req <- unmarshal_meta(req)
   req <- unmarshal(req)
@@ -657,13 +646,18 @@ test_that("unmarshal timestamp member", {
   op_output3 <- Structure(
     TimeMember = Scalar(type = "timestamp", .tags = list(timestampFormat = "unix")),
     StructMember = Structure(
-      Foo = Scalar(type = "timestamp", .tags = list(locationName = "foo", timestampFormat = "unix"))
+      Foo = Scalar(
+        type = "timestamp",
+        .tags = list(locationName = "foo", timestampFormat = "unix")
+      )
     )
   )
   req <- new_request(svc, op, NULL, op_output3)
   req$http_response <- HttpResponse(
     status_code = 200,
-    body = charToRaw("{\"TimeMember\": 1398796238, \"StructMember\": {\"foo\": 1398796238}}")
+    body = charToRaw(
+      "{\"TimeMember\": 1398796238, \"StructMember\": {\"foo\": 1398796238}}"
+    )
   )
   req <- unmarshal_meta(req)
   req <- unmarshal(req)
@@ -673,9 +667,7 @@ test_that("unmarshal timestamp member", {
 })
 
 test_that("unmarshal list", {
-  op_output4 <- Structure(
-    ListMember = List(Scalar(type = "string"))
-  )
+  op_output4 <- Structure(ListMember = List(Scalar(type = "string")))
   req <- new_request(svc, op, NULL, op_output4)
   req$http_response <- HttpResponse(
     status_code = 200,
@@ -689,13 +681,7 @@ test_that("unmarshal list", {
 })
 
 test_that("unmarshal list with structure member", {
-  op_output5 <- Structure(
-    ListMember = List(
-      Structure(
-        Foo = Scalar(type = "string")
-      )
-    )
-  )
+  op_output5 <- Structure(ListMember = List(Structure(Foo = Scalar(type = "string"))))
   req <- new_request(svc, op, NULL, op_output5)
   req$http_response <- HttpResponse(
     status_code = 200,
@@ -709,11 +695,7 @@ test_that("unmarshal list with structure member", {
 })
 
 test_that("unmarshal map", {
-  op_output6 <- Structure(
-    MapMember = Map(
-      List(Scalar(type = "integer"))
-    )
-  )
+  op_output6 <- Structure(MapMember = Map(List(Scalar(type = "integer"))))
   req <- new_request(svc, op, NULL, op_output6)
   req$http_response <- HttpResponse(
     status_code = 200,
@@ -729,11 +711,7 @@ test_that("unmarshal map", {
 })
 
 test_that("unmarshal map with timestamps", {
-  op_output7 <- Structure(
-    MapMember = Map(
-      Scalar(type = "timestamp")
-    )
-  )
+  op_output7 <- Structure(MapMember = Map(Scalar(type = "timestamp")))
   req <- new_request(svc, op, NULL, op_output7)
   req$http_response <- HttpResponse(
     status_code = 200,
@@ -747,9 +725,7 @@ test_that("unmarshal map with timestamps", {
 })
 
 test_that("unmarshal ignores extra data", {
-  op_output8 <- Structure(
-    StrType = Scalar(type = "string")
-  )
+  op_output8 <- Structure(StrType = Scalar(type = "string"))
   req <- new_request(svc, op, NULL, op_output8)
   req$http_response <- HttpResponse(
     status_code = 200,
@@ -765,12 +741,13 @@ test_that("unmarshal ignores extra data", {
 test_that("unmarshal header map", {
   op_output9 <- Structure(
     AllHeaders = Map(Scalar(type = "string"), .tags = list(location = "headers")),
-    PrefixedHeaders = Map(Scalar(type = "string"), .tags = list(location = "headers", locationName = "X-"))
+    PrefixedHeaders = Map(
+      Scalar(type = "string"),
+      .tags = list(location = "headers", locationName = "X-")
+    )
   )
   req <- new_request(svc, op, NULL, op_output9)
-  req$http_response <- HttpResponse(
-    status_code = 200
-  )
+  req$http_response <- HttpResponse(status_code = 200)
   req$http_response$header[["Content-Length"]] <- "10"
   req$http_response$header[["X-Bam"]] <- "boo"
   req$http_response$header[["X-Foo"]] <- "bar"
@@ -786,10 +763,11 @@ test_that("unmarshal header map", {
 
 test_that("JSON payload", {
   op_output10 <- Structure(
-    Data = Structure(
-      Foo = Scalar(type = "string")
+    Data = Structure(Foo = Scalar(type = "string")),
+    Header = Scalar(
+      type = "string",
+      .tags = list(location = "header", locationName = "X-Foo")
     ),
-    Header = Scalar(type = "string", .tags = list(location = "header", locationName = "X-Foo")),
     .tags = list(payload = "Data")
   )
   req <- new_request(svc, op, NULL, op_output10)
@@ -812,7 +790,10 @@ test_that("JSON payload", {
 test_that("unmarshal blob payload", {
   op_output14 <- Structure(
     Data = Scalar(type = "blob"),
-    Header = Scalar(type = "string", .tags = list(location = "header", locationName = "X-Foo")),
+    Header = Scalar(
+      type = "string",
+      .tags = list(location = "header", locationName = "X-Foo")
+    ),
     .tags = list(payload = "Data")
   )
   req <- new_request(svc, op, NULL, op_output14)
@@ -838,7 +819,9 @@ test_that("unmarshal error without header and with error code in response", {
   req <- new_request(svc, op, NULL, NULL)
   req$http_response <- HttpResponse(
     status_code = 400,
-    body = charToRaw("{\"message\":\"foo\",\"code\":\"bar\",\"__type\":\"ClientException\"}")
+    body = charToRaw(
+      "{\"message\":\"foo\",\"code\":\"bar\",\"__type\":\"ClientException\"}"
+    )
   )
   req <- unmarshal_error(req)
   err <- req$error
