@@ -12,7 +12,10 @@ test_that("new endpoint with default port", {
 
 test_that("sanitize_host_for_header", {
   cases <- list(
-    c("https://estest.us-east-1.es.amazonaws.com:443", "estest.us-east-1.es.amazonaws.com"),
+    c(
+      "https://estest.us-east-1.es.amazonaws.com:443",
+      "estest.us-east-1.es.amazonaws.com"
+    ),
     c("https://estest.us-east-1.es.amazonaws.com", "estest.us-east-1.es.amazonaws.com"),
     c("https://localhost:9200", "localhost:9200"),
     c("http://localhost:80", "localhost"),
